<div class="field">
    <div class="control">
        <textarea name="{{ widget.name }}"
                  class="textarea"
                  {% include "django/forms/widgets/attrs.html" %}
        >{% if widget.value %}{{ widget.value }}{% endif %}</textarea>
    </div>
</div>