{% extends 'ui/form.html' %}

{% block form %}
    <form id="form" method="post" action="">
    {% csrf_token %}
    <div class="columns">
        <div class="column is-6">
            <label class="label has-field is-required">
                {{ form.old_password.label_tag }}
                <span class="has-text-danger is-size-7">{{ form.old_password.errors }}</span>
                <div class="field">
                    <p class="control is-fullwidth">{{ form.old_password }}</p>
                </div>
            </label>
        </div>
    </div>
    <div class="columns">
        <div class="column is-6">
            <label class="label has-field is-required">
                {{ form.new_password.label_tag }}
                <span class="has-text-danger is-size-7">{{ form.new_password.errors }}</span>
                <div class="field">
                    <p class="control is-fullwidth">{{ form.new_password }}</p>
                </div>
            </label>
        </div>
    </div>
    <div class="columns">
        <div class="column is-6">
            <label class="label has-field is-required">
                {{ form.new_password_confirm.label_tag }}
                <span class="has-text-danger is-size-7">{{ form.new_password_confirm.errors }}</span>
                <div class="field">
                    <p class="control is-fullwidth">{{ form.new_password_confirm }}</p>
                </div>
            </label>
        </div>
    </div>
</form>
{% endblock %}
